/*******************************************************************************
 * Copyright 2003 Seapine Software, Inc. All rights reserved.
 * 
 * IMPORTANT:  This Software is supplied to you by Seapine Software, Inc. (Seapine)
 * in consideration of your agreement to the following terms, and your use, installation,
 * modification or redistribution of this Software constitutes acceptance of these terms.
 * If you do not agree with these terms, please do not use, install, modify or redistribute
 * this Software.
 * 
 * In consideration of your agreement to abide by the following terms, and subject to these
 * terms, Seapine grants you a personal, non-exclusive license, under Seapine copyrights in
 * this original Seapine software (the Software), to use, reproduce, modify and redistribute
 * the Software, with or without modifications, in source and/or binary forms; provided that
 * if you redistribute the Software in its entirety and without modifications, you must retain
 * this notice and the following text and disclaimers in all such redistributions of the Software.
 * Neither the name, trademarks, service marks or logos of Seapine, Inc. may be used to endorse
 * or promote products derived from the Software without specific prior written permission from
 * Seapine.  Except as expressly stated in this notice, no other rights or licenses, express or
 * implied, are granted by Seapine herein, including but not limited to any patent rights that
 * may be infringed by your derivative works or by other works in which the Software may be
 * incorporated.
 * 
 * The Software is provided by Seapine on an "AS IS" basis.  SEAPINE MAKES NO WARRANTIES,
 * EXPRESS OR IMPLIED, INCLUDING WITHOUT LIMITATION THE IMPLIED WARRANTIES OF NON-INFRINGEMENT,
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE, REGARDING THE SOFTWARE OR ITS USE AND
 * OPERATION ALONE OR IN COMBINATION WITH YOUR PRODUCTS. 
 * 
 * IN NO EVENT SHALL SEAPINE BE LIABLE FOR ANY SPECIAL, INDIRECT, INCIDENTAL OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) ARISING IN ANY WAY OUT OF THE USE,
 * REPRODUCTION, MODIFICATION AND/OR DISTRIBUTION OF THE SOFTWARE, HOWEVER CAUSED AND WHETHER
 * UNDER THEORY OF CONTRACT, TORT (INCLUDING NEGLIGENCE), STRICT LIABILITY OR OTHERWISE, EVEN
 * IF SEAPINE HAS BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 ******************************************************************************/

#include <stdio.h>
#include <stdlib.h>
#include <string.h>

//////////////////////////////////////////////////////////////////////////////

// This is the log file that is written to.  You may specify any valid file
// here to write to a different log file.
const char sLog[] = "C:\\SCMSampleLog.txt";

//////////////////////////////////////////////////////////////////////////////

// These variables are the ones retrieved from the environment that the
// SCM trigger sets for us.
const char *sTriggerDesc = NULL;
const char *sTriggerEvent = NULL;
const char *sTriggerBeforeAfter = NULL;
const char *sTriggerDate = NULL;
const char *sTriggerTime = NULL;
const char *sTriggerUser = NULL;
const char *sTriggerClientIP = NULL;
const char *sTriggerClientMachine = NULL;
const char *sTriggerMainline = NULL;
const char *sTriggerBranch = NULL;
const char *sTriggerBranchType = NULL;
const char *sTriggerRepository = NULL;
const char *sTriggerFile = NULL;
const char *sTriggerFileVersion = NULL;
const char *sTriggerLocalFile = NULL;
const char *sTriggerComment = NULL;
const char *sTriggerSourceBranch = NULL;
const char *sTriggerDefectNumber = NULL;
const char *sTriggerShareRepository = NULL;
const char *sTriggerOldFileName = NULL;
const char *sTriggerPermRemove = NULL;

//////////////////////////////////////////////////////////////////////////////

int main(int argc, char **argv)
{
   int nReturn = 0;
   FILE *fpLog = NULL;
   if(!(fpLog = fopen(sLog, "a")))
      return -1;  // Error opening error log, and no way to report it.

   // Get all of Surround SCM's environment variables (some may go unused)
   sTriggerDesc = getenv("SSCM_TRIGGERDESC");
   sTriggerEvent = getenv("SSCM_EVENT");
   sTriggerBeforeAfter = getenv("SSCM_BEFOREAFTER");
   sTriggerDate = getenv("SSCM_DATE");
   sTriggerTime = getenv("SSCM_TIME");
   sTriggerUser = getenv("SSCM_USER");
   sTriggerClientIP = getenv("SSCM_CLIENTIP");
   sTriggerClientMachine = getenv("SSCM_CLIENTMACHINE");
   sTriggerMainline = getenv("SSCM_MAINLINE");
   sTriggerBranch = getenv("SSCM_BRANCH");
   sTriggerBranchType = getenv("SSCM_BRANCHTYPE");
   sTriggerRepository = getenv("SSCM_REPOSITORY");
   sTriggerFile = getenv("SSCM_FILE");
   sTriggerFileVersion = getenv("SSCM_FILEVERSION");
   sTriggerLocalFile = getenv("SSCM_LOCALFILE");
   sTriggerComment = getenv("SSCM_COMMENT");
   sTriggerSourceBranch = getenv("SSCM_SOURCEBRANCH");
   sTriggerDefectNumber = getenv("SSCM_DEFECTNUMBER");
   sTriggerShareRepository = getenv("SSCM_SHAREREPOSITORY");
   sTriggerOldFileName = getenv("SSCM_OLDFILENAME");
   sTriggerPermRemove = getenv("SSCM_PERMREMOVE");

   // Output all variables to the log
   fprintf(fpLog, "Trigger \"%s\" was fired on %s at %s.\n",
                  sTriggerDesc, sTriggerDate, sTriggerTime);
   fprintf(fpLog, "  %s was fired %s %s.\n",
                  sTriggerDesc, sTriggerBeforeAfter, sTriggerEvent);
   fprintf(fpLog, "  %s (%s - %s) performed a %s\n",
                  sTriggerUser, sTriggerClientIP, sTriggerClientMachine, sTriggerEvent);
   fprintf(fpLog, "    in the mainline %s\n",
                  sTriggerMainline);
   fprintf(fpLog, "    in the branch %s of type %s\n",
                  sTriggerBranch, sTriggerBranchType);
   fprintf(fpLog, "    on the file %s/%s\n",
                  sTriggerRepository, sTriggerFile);

   if(sTriggerDefectNumber  &&  sTriggerDefectNumber[0] != 0)
      fprintf(fpLog, "      Attached to defect number %s\n", sTriggerDefectNumber);

   if(sTriggerSourceBranch  &&  sTriggerSourceBranch[0] != 0)
      fprintf(fpLog, "      %s from branch %s to %s\n",
                     sTriggerEvent, sTriggerSourceBranch, sTriggerBranch);

   if(sTriggerFileVersion  &&  sTriggerFileVersion[0] != 0)
      fprintf(fpLog, "      The new file version is %s.\n", sTriggerFileVersion);

   if(sTriggerLocalFile  &&  sTriggerLocalFile[0] != 0)
      fprintf(fpLog, "      The local file was accessible via %s\n",
                     sTriggerLocalFile);

   if(sTriggerShareRepository  &&  sTriggerShareRepository[0] != 0)
      fprintf(fpLog, "      The file was shared from %s\n",
                     sTriggerShareRepository);

   if(sTriggerOldFileName  &&  sTriggerOldFileName[0] != 0)
      fprintf(fpLog, "      The file was renamed from %s to %s\n",
                     sTriggerOldFileName, sTriggerFile);

   if(sTriggerPermRemove  &&  strcmp(sTriggerPermRemove, "yes") == 0)
      fprintf(fpLog, "      The file was permanently removed.\n");

   fprintf(fpLog, "\n");

   fclose(fpLog);
   return nReturn;
}

//////////////////////////////////////////////////////////////////////////////
